# coding: utf-8

"""
    Synctera API

    <h2>Let's build something great.</h2><p>Welcome to the official reference documentation for Synctera APIs. Our APIs are the best way to automate your company's banking needs and are designed to be easy to understand and implement.</p><p>We're continuously growing this library and what you see here is just the start, but if you need something specific or have a question, <a class='text-blue-600' href='https://synctera.com/contact' target='_blank' rel='noreferrer'>contact us</a>.</p>  # noqa: E501

    The version of the OpenAPI document: 0.41.0
    Contact: dev@swadesh.co
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


from __future__ import absolute_import

import re  # noqa: F401

from pydantic import validate_arguments, ValidationError
from typing_extensions import Annotated

from datetime import date

from pydantic import Field, StrictBool, StrictStr, conint, conlist, constr, validator

from typing import Optional

from synctera_client_ng.models.pending_transaction import PendingTransaction
from synctera_client_ng.models.pending_transactions import PendingTransactions
from synctera_client_ng.models.posted_transaction import PostedTransaction
from synctera_client_ng.models.posted_transactions import PostedTransactions

from synctera_client_ng.api_client import ApiClient
from synctera_client_ng.exceptions import (  # noqa: F401
    ApiTypeError,
    ApiValueError
)


class TransactionsApi(object):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient.get_default()
        self.api_client = api_client

    @validate_arguments
    def get_pending_transaction_by_id(self, id : Annotated[StrictStr, Field(..., description="Transaction ID")], **kwargs) -> PendingTransaction:  # noqa: E501
        """Get a pending transaction  # noqa: E501

        Get a pending transaction by its uuid   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_pending_transaction_by_id(id, async_req=True)
        >>> result = thread.get()

        :param id: Transaction ID (required)
        :type id: str
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: PendingTransaction
        """
        kwargs['_return_http_data_only'] = True
        return self.get_pending_transaction_by_id_with_http_info(id, **kwargs)  # noqa: E501

    @validate_arguments
    def get_pending_transaction_by_id_with_http_info(self, id : Annotated[StrictStr, Field(..., description="Transaction ID")], **kwargs):  # noqa: E501
        """Get a pending transaction  # noqa: E501

        Get a pending transaction by its uuid   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_pending_transaction_by_id_with_http_info(id, async_req=True)
        >>> result = thread.get()

        :param id: Transaction ID (required)
        :type id: str
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _return_http_data_only: response data without head status code
                                       and headers
        :type _return_http_data_only: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(PendingTransaction, status_code(int), headers(HTTPHeaderDict))
        """

        _params = locals()

        _all_params = [
            'id'
        ]
        _all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout',
                '_request_auth',
                '_content_type',
                '_headers'
            ]
        )

        # validate the arguments
        for _key, _val in _params['kwargs'].items():
            if _key not in _all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_pending_transaction_by_id" % _key
                )
            _params[_key] = _val
        del _params['kwargs']

        _collection_formats = {}

        # process the path parameters
        _path_params = {}
        if _params['id']:
            _path_params['id'] = _params['id']


        # process the query parameters
        _query_params = []
        # process the header parameters
        _header_params = dict(_params.get('_headers', {}))
        # process the form parameters
        _form_params = []
        _files = {}
        # process the body parameter
        _body_params = None
        # set the HTTP header `Accept`
        _header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/problem+json'])  # noqa: E501

        # authentication setting
        _auth_settings = ['bearerAuth']  # noqa: E501

        _response_types_map = {
            '200': "PendingTransaction",
            '400': "Error",
            '401': "Error",
            '403': "Error",
            '422': "Error",
            '500': "Error",
        }

        return self.api_client.call_api(
            '/transactions/pending/{id}', 'GET',
            _path_params,
            _query_params,
            _header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            response_types_map=_response_types_map,
            auth_settings=_auth_settings,
            async_req=_params.get('async_req'),
            _return_http_data_only=_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=_params.get('_preload_content', True),
            _request_timeout=_params.get('_request_timeout'),
            collection_formats=_collection_formats,
            _request_auth=_params.get('_request_auth'))

    @validate_arguments
    def get_posted_transaction_by_id(self, id : Annotated[StrictStr, Field(..., description="Transaction ID")], **kwargs) -> PostedTransaction:  # noqa: E501
        """Get a posted transaction  # noqa: E501

        Get a posted transaction by its uuid   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_posted_transaction_by_id(id, async_req=True)
        >>> result = thread.get()

        :param id: Transaction ID (required)
        :type id: str
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: PostedTransaction
        """
        kwargs['_return_http_data_only'] = True
        return self.get_posted_transaction_by_id_with_http_info(id, **kwargs)  # noqa: E501

    @validate_arguments
    def get_posted_transaction_by_id_with_http_info(self, id : Annotated[StrictStr, Field(..., description="Transaction ID")], **kwargs):  # noqa: E501
        """Get a posted transaction  # noqa: E501

        Get a posted transaction by its uuid   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_posted_transaction_by_id_with_http_info(id, async_req=True)
        >>> result = thread.get()

        :param id: Transaction ID (required)
        :type id: str
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _return_http_data_only: response data without head status code
                                       and headers
        :type _return_http_data_only: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(PostedTransaction, status_code(int), headers(HTTPHeaderDict))
        """

        _params = locals()

        _all_params = [
            'id'
        ]
        _all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout',
                '_request_auth',
                '_content_type',
                '_headers'
            ]
        )

        # validate the arguments
        for _key, _val in _params['kwargs'].items():
            if _key not in _all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_posted_transaction_by_id" % _key
                )
            _params[_key] = _val
        del _params['kwargs']

        _collection_formats = {}

        # process the path parameters
        _path_params = {}
        if _params['id']:
            _path_params['id'] = _params['id']


        # process the query parameters
        _query_params = []
        # process the header parameters
        _header_params = dict(_params.get('_headers', {}))
        # process the form parameters
        _form_params = []
        _files = {}
        # process the body parameter
        _body_params = None
        # set the HTTP header `Accept`
        _header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/problem+json'])  # noqa: E501

        # authentication setting
        _auth_settings = ['bearerAuth']  # noqa: E501

        _response_types_map = {
            '200': "PostedTransaction",
            '400': "Error",
            '401': "Error",
            '403': "Error",
            '422': "Error",
            '500': "Error",
        }

        return self.api_client.call_api(
            '/transactions/posted/{id}', 'GET',
            _path_params,
            _query_params,
            _header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            response_types_map=_response_types_map,
            auth_settings=_auth_settings,
            async_req=_params.get('async_req'),
            _return_http_data_only=_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=_params.get('_preload_content', True),
            _request_timeout=_params.get('_request_timeout'),
            collection_formats=_collection_formats,
            _request_auth=_params.get('_request_auth'))

    @validate_arguments
    def list_pending_transactions(self, account_no : Annotated[Optional[StrictStr], Field(description="Account number")] = None, account_id : Annotated[Optional[StrictStr], Field(description="Account ID")] = None, from_date : Annotated[Optional[date], Field(description="Only display transactions with a posting date greater than from_date")] = None, to_date : Annotated[Optional[date], Field(description="Only display transactions with a posting date less than or equal to to_date")] = None, status : Annotated[Optional[conlist(StrictStr)], Field(description="The status of the transaction")] = None, transaction_id : Annotated[Optional[StrictStr], Field(description="Only display holds linked to the provided transaction id")] = None, tenant : Optional[constr(strict=True)] = None, type : Annotated[Optional[StrictStr], Field(description="Only display transactions matching the given type")] = None, subtype : Annotated[Optional[StrictStr], Field(description="Only display transactions matching the given subtype")] = None, limit : Optional[conint(strict=True, ge=1)] = None, page_token : Optional[StrictStr] = None, **kwargs) -> PendingTransactions:  # noqa: E501
        """List pending transactions  # noqa: E501

        Get paginated list of pending transactions matching the provided filters   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.list_pending_transactions(account_no, account_id, from_date, to_date, status, transaction_id, tenant, type, subtype, limit, page_token, async_req=True)
        >>> result = thread.get()

        :param account_no: Account number
        :type account_no: str
        :param account_id: Account ID
        :type account_id: str
        :param from_date: Only display transactions with a posting date greater than from_date
        :type from_date: date
        :param to_date: Only display transactions with a posting date less than or equal to to_date
        :type to_date: date
        :param status: The status of the transaction
        :type status: List[str]
        :param transaction_id: Only display holds linked to the provided transaction id
        :type transaction_id: str
        :param tenant:
        :type tenant: str
        :param type: Only display transactions matching the given type
        :type type: str
        :param subtype: Only display transactions matching the given subtype
        :type subtype: str
        :param limit:
        :type limit: int
        :param page_token:
        :type page_token: str
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: PendingTransactions
        """
        kwargs['_return_http_data_only'] = True
        return self.list_pending_transactions_with_http_info(account_no, account_id, from_date, to_date, status, transaction_id, tenant, type, subtype, limit, page_token, **kwargs)  # noqa: E501

    @validate_arguments
    def list_pending_transactions_with_http_info(self, account_no : Annotated[Optional[StrictStr], Field(description="Account number")] = None, account_id : Annotated[Optional[StrictStr], Field(description="Account ID")] = None, from_date : Annotated[Optional[date], Field(description="Only display transactions with a posting date greater than from_date")] = None, to_date : Annotated[Optional[date], Field(description="Only display transactions with a posting date less than or equal to to_date")] = None, status : Annotated[Optional[conlist(StrictStr)], Field(description="The status of the transaction")] = None, transaction_id : Annotated[Optional[StrictStr], Field(description="Only display holds linked to the provided transaction id")] = None, tenant : Optional[constr(strict=True)] = None, type : Annotated[Optional[StrictStr], Field(description="Only display transactions matching the given type")] = None, subtype : Annotated[Optional[StrictStr], Field(description="Only display transactions matching the given subtype")] = None, limit : Optional[conint(strict=True, ge=1)] = None, page_token : Optional[StrictStr] = None, **kwargs):  # noqa: E501
        """List pending transactions  # noqa: E501

        Get paginated list of pending transactions matching the provided filters   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.list_pending_transactions_with_http_info(account_no, account_id, from_date, to_date, status, transaction_id, tenant, type, subtype, limit, page_token, async_req=True)
        >>> result = thread.get()

        :param account_no: Account number
        :type account_no: str
        :param account_id: Account ID
        :type account_id: str
        :param from_date: Only display transactions with a posting date greater than from_date
        :type from_date: date
        :param to_date: Only display transactions with a posting date less than or equal to to_date
        :type to_date: date
        :param status: The status of the transaction
        :type status: List[str]
        :param transaction_id: Only display holds linked to the provided transaction id
        :type transaction_id: str
        :param tenant:
        :type tenant: str
        :param type: Only display transactions matching the given type
        :type type: str
        :param subtype: Only display transactions matching the given subtype
        :type subtype: str
        :param limit:
        :type limit: int
        :param page_token:
        :type page_token: str
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _return_http_data_only: response data without head status code
                                       and headers
        :type _return_http_data_only: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(PendingTransactions, status_code(int), headers(HTTPHeaderDict))
        """

        _params = locals()

        _all_params = [
            'account_no',
            'account_id',
            'from_date',
            'to_date',
            'status',
            'transaction_id',
            'tenant',
            'type',
            'subtype',
            'limit',
            'page_token'
        ]
        _all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout',
                '_request_auth',
                '_content_type',
                '_headers'
            ]
        )

        # validate the arguments
        for _key, _val in _params['kwargs'].items():
            if _key not in _all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method list_pending_transactions" % _key
                )
            _params[_key] = _val
        del _params['kwargs']

        _collection_formats = {}

        # process the path parameters
        _path_params = {}

        # process the query parameters
        _query_params = []
        if _params.get('account_no') is not None:  # noqa: E501
            _query_params.append(('account_no', _params['account_no']))

        if _params.get('account_id') is not None:  # noqa: E501
            _query_params.append(('account_id', _params['account_id']))

        if _params.get('from_date') is not None:  # noqa: E501
            if isinstance(_params['from_date'], datetime):
                _query_parame.append(('from_date', _params['from_date'].strftime(self.api_client.configuration.date_format)))
            else:
                _query_params.append(('from_date', _params['from_date']))

        if _params.get('to_date') is not None:  # noqa: E501
            if isinstance(_params['to_date'], datetime):
                _query_parame.append(('to_date', _params['to_date'].strftime(self.api_client.configuration.date_format)))
            else:
                _query_params.append(('to_date', _params['to_date']))

        if _params.get('status') is not None:  # noqa: E501
            _query_params.append(('status', _params['status']))
            _collection_formats['status'] = 'csv'

        if _params.get('transaction_id') is not None:  # noqa: E501
            _query_params.append(('transaction_id', _params['transaction_id']))

        if _params.get('tenant') is not None:  # noqa: E501
            _query_params.append(('tenant', _params['tenant']))

        if _params.get('type') is not None:  # noqa: E501
            _query_params.append(('type', _params['type']))

        if _params.get('subtype') is not None:  # noqa: E501
            _query_params.append(('subtype', _params['subtype']))

        if _params.get('limit') is not None:  # noqa: E501
            _query_params.append(('limit', _params['limit']))

        if _params.get('page_token') is not None:  # noqa: E501
            _query_params.append(('page_token', _params['page_token']))

        # process the header parameters
        _header_params = dict(_params.get('_headers', {}))
        # process the form parameters
        _form_params = []
        _files = {}
        # process the body parameter
        _body_params = None
        # set the HTTP header `Accept`
        _header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/problem+json'])  # noqa: E501

        # authentication setting
        _auth_settings = ['bearerAuth']  # noqa: E501

        _response_types_map = {
            '200': "PendingTransactions",
            '400': "Error",
            '401': "Error",
            '403': "Error",
            '422': "Error",
            '500': "Error",
        }

        return self.api_client.call_api(
            '/transactions/pending', 'GET',
            _path_params,
            _query_params,
            _header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            response_types_map=_response_types_map,
            auth_settings=_auth_settings,
            async_req=_params.get('async_req'),
            _return_http_data_only=_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=_params.get('_preload_content', True),
            _request_timeout=_params.get('_request_timeout'),
            collection_formats=_collection_formats,
            _request_auth=_params.get('_request_auth'))

    @validate_arguments
    def list_posted_transactions(self, uuid : Annotated[Optional[conlist(StrictStr)], Field(description="Transaction UUID(s). Multiple UUIDs can be provided as a comma-separated list.")] = None, account_no : Annotated[Optional[StrictStr], Field(description="Account number")] = None, account_id : Annotated[Optional[StrictStr], Field(description="Account ID")] = None, from_date : Annotated[Optional[date], Field(description="Only display transactions with a posting date greater than from_date")] = None, to_date : Annotated[Optional[date], Field(description="Only display transactions with a posting date less than or equal to to_date")] = None, tenant : Optional[constr(strict=True)] = None, account_alias : Annotated[Optional[StrictStr], Field(description="Only display transactions involving the account with the given alias")] = None, type : Annotated[Optional[StrictStr], Field(description="Only display transactions matching the given type")] = None, subtype : Annotated[Optional[StrictStr], Field(description="Only display transactions matching the given subtype")] = None, include_info_only : Annotated[Optional[StrictBool], Field(description="Include info_only transactions in the response")] = None, limit : Optional[conint(strict=True, ge=1)] = None, page_token : Optional[StrictStr] = None, **kwargs) -> PostedTransactions:  # noqa: E501
        """List posted transactions  # noqa: E501

        Get paginated list of posted transactions matching the provided filters   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.list_posted_transactions(uuid, account_no, account_id, from_date, to_date, tenant, account_alias, type, subtype, include_info_only, limit, page_token, async_req=True)
        >>> result = thread.get()

        :param uuid: Transaction UUID(s). Multiple UUIDs can be provided as a comma-separated list.
        :type uuid: List[str]
        :param account_no: Account number
        :type account_no: str
        :param account_id: Account ID
        :type account_id: str
        :param from_date: Only display transactions with a posting date greater than from_date
        :type from_date: date
        :param to_date: Only display transactions with a posting date less than or equal to to_date
        :type to_date: date
        :param tenant:
        :type tenant: str
        :param account_alias: Only display transactions involving the account with the given alias
        :type account_alias: str
        :param type: Only display transactions matching the given type
        :type type: str
        :param subtype: Only display transactions matching the given subtype
        :type subtype: str
        :param include_info_only: Include info_only transactions in the response
        :type include_info_only: bool
        :param limit:
        :type limit: int
        :param page_token:
        :type page_token: str
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: PostedTransactions
        """
        kwargs['_return_http_data_only'] = True
        return self.list_posted_transactions_with_http_info(uuid, account_no, account_id, from_date, to_date, tenant, account_alias, type, subtype, include_info_only, limit, page_token, **kwargs)  # noqa: E501

    @validate_arguments
    def list_posted_transactions_with_http_info(self, uuid : Annotated[Optional[conlist(StrictStr)], Field(description="Transaction UUID(s). Multiple UUIDs can be provided as a comma-separated list.")] = None, account_no : Annotated[Optional[StrictStr], Field(description="Account number")] = None, account_id : Annotated[Optional[StrictStr], Field(description="Account ID")] = None, from_date : Annotated[Optional[date], Field(description="Only display transactions with a posting date greater than from_date")] = None, to_date : Annotated[Optional[date], Field(description="Only display transactions with a posting date less than or equal to to_date")] = None, tenant : Optional[constr(strict=True)] = None, account_alias : Annotated[Optional[StrictStr], Field(description="Only display transactions involving the account with the given alias")] = None, type : Annotated[Optional[StrictStr], Field(description="Only display transactions matching the given type")] = None, subtype : Annotated[Optional[StrictStr], Field(description="Only display transactions matching the given subtype")] = None, include_info_only : Annotated[Optional[StrictBool], Field(description="Include info_only transactions in the response")] = None, limit : Optional[conint(strict=True, ge=1)] = None, page_token : Optional[StrictStr] = None, **kwargs):  # noqa: E501
        """List posted transactions  # noqa: E501

        Get paginated list of posted transactions matching the provided filters   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.list_posted_transactions_with_http_info(uuid, account_no, account_id, from_date, to_date, tenant, account_alias, type, subtype, include_info_only, limit, page_token, async_req=True)
        >>> result = thread.get()

        :param uuid: Transaction UUID(s). Multiple UUIDs can be provided as a comma-separated list.
        :type uuid: List[str]
        :param account_no: Account number
        :type account_no: str
        :param account_id: Account ID
        :type account_id: str
        :param from_date: Only display transactions with a posting date greater than from_date
        :type from_date: date
        :param to_date: Only display transactions with a posting date less than or equal to to_date
        :type to_date: date
        :param tenant:
        :type tenant: str
        :param account_alias: Only display transactions involving the account with the given alias
        :type account_alias: str
        :param type: Only display transactions matching the given type
        :type type: str
        :param subtype: Only display transactions matching the given subtype
        :type subtype: str
        :param include_info_only: Include info_only transactions in the response
        :type include_info_only: bool
        :param limit:
        :type limit: int
        :param page_token:
        :type page_token: str
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _return_http_data_only: response data without head status code
                                       and headers
        :type _return_http_data_only: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(PostedTransactions, status_code(int), headers(HTTPHeaderDict))
        """

        _params = locals()

        _all_params = [
            'uuid',
            'account_no',
            'account_id',
            'from_date',
            'to_date',
            'tenant',
            'account_alias',
            'type',
            'subtype',
            'include_info_only',
            'limit',
            'page_token'
        ]
        _all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout',
                '_request_auth',
                '_content_type',
                '_headers'
            ]
        )

        # validate the arguments
        for _key, _val in _params['kwargs'].items():
            if _key not in _all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method list_posted_transactions" % _key
                )
            _params[_key] = _val
        del _params['kwargs']

        _collection_formats = {}

        # process the path parameters
        _path_params = {}

        # process the query parameters
        _query_params = []
        if _params.get('uuid') is not None:  # noqa: E501
            _query_params.append(('uuid', _params['uuid']))
            _collection_formats['uuid'] = 'csv'

        if _params.get('account_no') is not None:  # noqa: E501
            _query_params.append(('account_no', _params['account_no']))

        if _params.get('account_id') is not None:  # noqa: E501
            _query_params.append(('account_id', _params['account_id']))

        if _params.get('from_date') is not None:  # noqa: E501
            if isinstance(_params['from_date'], datetime):
                _query_parame.append(('from_date', _params['from_date'].strftime(self.api_client.configuration.date_format)))
            else:
                _query_params.append(('from_date', _params['from_date']))

        if _params.get('to_date') is not None:  # noqa: E501
            if isinstance(_params['to_date'], datetime):
                _query_parame.append(('to_date', _params['to_date'].strftime(self.api_client.configuration.date_format)))
            else:
                _query_params.append(('to_date', _params['to_date']))

        if _params.get('tenant') is not None:  # noqa: E501
            _query_params.append(('tenant', _params['tenant']))

        if _params.get('account_alias') is not None:  # noqa: E501
            _query_params.append(('account_alias', _params['account_alias']))

        if _params.get('type') is not None:  # noqa: E501
            _query_params.append(('type', _params['type']))

        if _params.get('subtype') is not None:  # noqa: E501
            _query_params.append(('subtype', _params['subtype']))

        if _params.get('include_info_only') is not None:  # noqa: E501
            _query_params.append(('include_info_only', _params['include_info_only']))

        if _params.get('limit') is not None:  # noqa: E501
            _query_params.append(('limit', _params['limit']))

        if _params.get('page_token') is not None:  # noqa: E501
            _query_params.append(('page_token', _params['page_token']))

        # process the header parameters
        _header_params = dict(_params.get('_headers', {}))
        # process the form parameters
        _form_params = []
        _files = {}
        # process the body parameter
        _body_params = None
        # set the HTTP header `Accept`
        _header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/problem+json'])  # noqa: E501

        # authentication setting
        _auth_settings = ['bearerAuth']  # noqa: E501

        _response_types_map = {
            '200': "PostedTransactions",
            '400': "Error",
            '401': "Error",
            '403': "Error",
            '422': "Error",
            '500': "Error",
        }

        return self.api_client.call_api(
            '/transactions/posted', 'GET',
            _path_params,
            _query_params,
            _header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            response_types_map=_response_types_map,
            auth_settings=_auth_settings,
            async_req=_params.get('async_req'),
            _return_http_data_only=_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=_params.get('_preload_content', True),
            _request_timeout=_params.get('_request_timeout'),
            collection_formats=_collection_formats,
            _request_auth=_params.get('_request_auth'))



# coding: utf-8

"""
    Synctera API

    <h2>Let's build something great.</h2><p>Welcome to the official reference documentation for Synctera APIs. Our APIs are the best way to automate your company's banking needs and are designed to be easy to understand and implement.</p><p>We're continuously growing this library and what you see here is just the start, but if you need something specific or have a question, <a class='text-blue-600' href='https://synctera.com/contact' target='_blank' rel='noreferrer'>contact us</a>.</p>  # noqa: E501

    The version of the OpenAPI document: 0.41.0
    Contact: dev@swadesh.co
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


from __future__ import annotations
from inspect import getfullargspec
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from typing import Any, Dict, List, Optional
from pydantic import BaseModel, Field, StrictStr, conlist
from synctera_client_ng.models.detail import Detail
from synctera_client_ng.models.vendor_info import VendorInfo
from synctera_client_ng.models.verification_result import VerificationResult
from synctera_client_ng.models.verification_type1 import VerificationType1

class Verification(BaseModel):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """
    business_id: Optional[StrictStr] = Field(None, description="Unique ID for the business. Exactly one of `business_id` or `person_id` must be set. ")
    creation_time: Optional[datetime] = Field(None, description="The date and time the resource was created.")
    details: Optional[conlist(Detail)] = Field(None, description="A list of individual checks done as part of the due diligence process for the verification type. ")
    id: Optional[StrictStr] = Field(None, description="Unique ID for this verification result.")
    last_updated_time: Optional[datetime] = Field(None, description="The date and time the resource was last updated.")
    metadata: Optional[Dict[str, Any]] = Field(None, description="Optional field to store additional information about the resource. Intended to be used by the integrator to store non-sensitive data. ")
    person_id: Optional[StrictStr] = Field(None, description="Unique ID for the person. Exactly one of `person_id` or `business_id` must be set. ")
    result: VerificationResult = ...
    vendor_info: Optional[VendorInfo] = None
    verification_time: datetime = Field(..., description="The date and time the verification was completed.")
    verification_type: VerificationType1 = ...
    __properties = ["business_id", "creation_time", "details", "id", "last_updated_time", "metadata", "person_id", "result", "vendor_info", "verification_time", "verification_type"]

    class Config:
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Verification:
        """Create an instance of Verification from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                            "creation_time",
                            "details",
                            "id",
                            "last_updated_time",
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of each item in details (list)
        _items = []
        if self.details:
            for _item in self.details:
                if _item:
                    _items.append(_item.to_dict())
            _dict['details'] = _items
        # override the default output from pydantic by calling `to_dict()` of vendor_info
        if self.vendor_info:
            _dict['vendor_info'] = self.vendor_info.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> Verification:
        """Create an instance of Verification from a dict"""
        if obj is None:
            return None

        if type(obj) is not dict:
            return Verification.parse_obj(obj)

        _obj = Verification.parse_obj({
            "business_id": obj.get("business_id"),
            "creation_time": obj.get("creation_time"),
            "details": [Detail.from_dict(_item) for _item in obj.get("details")] if obj.get("details") is not None else None,
            "id": obj.get("id"),
            "last_updated_time": obj.get("last_updated_time"),
            "metadata": obj.get("metadata"),
            "person_id": obj.get("person_id"),
            "result": obj.get("result"),
            "vendor_info": VendorInfo.from_dict(obj.get("vendor_info")) if obj.get("vendor_info") is not None else None,
            "verification_time": obj.get("verification_time"),
            "verification_type": obj.get("verification_type")
        })
        return _obj




# coding: utf-8

"""
    Synctera API

    <h2>Let's build something great.</h2><p>Welcome to the official reference documentation for Synctera APIs. Our APIs are the best way to automate your company's banking needs and are designed to be easy to understand and implement.</p><p>We're continuously growing this library and what you see here is just the start, but if you need something specific or have a question, <a class='text-blue-600' href='https://synctera.com/contact' target='_blank' rel='noreferrer'>contact us</a>.</p>  # noqa: E501

    The version of the OpenAPI document: 0.41.0
    Contact: dev@swadesh.co
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


from __future__ import annotations
from inspect import getfullargspec
import pprint
import re  # noqa: F401
import json


from typing import Optional
from pydantic import BaseModel, Field, StrictStr, constr
from synctera_client_ng.models.card_fulfillment_status import CardFulfillmentStatus
from synctera_client_ng.models.card_status import CardStatus
from synctera_client_ng.models.card_status_reason_code import CardStatusReasonCode
from synctera_client_ng.models.fulfillment_details import FulfillmentDetails

class PhysicalCardResponseStatus(BaseModel):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """
    card_status: CardStatus = ...
    memo: Optional[constr(strict=True, max_length=255)] = Field(None, description="Additional details about the reason for the status change")
    status_reason: CardStatusReasonCode = ...
    card_fulfillment_status: CardFulfillmentStatus = ...
    fulfillment_details: Optional[FulfillmentDetails] = None
    tracking_number: Optional[StrictStr] = Field(None, description="This contains all shipping details as provided by the card fulfillment provider, including the tracking number. This field is deprecated. Instead, please use the fulfillment_details object, which includes a field for just the tracking number. ")
    __properties = ["card_status", "memo", "status_reason", "card_fulfillment_status", "fulfillment_details", "tracking_number"]

    class Config:
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> PhysicalCardResponseStatus:
        """Create an instance of PhysicalCardResponseStatus from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                            "tracking_number",
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of fulfillment_details
        if self.fulfillment_details:
            _dict['fulfillment_details'] = self.fulfillment_details.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> PhysicalCardResponseStatus:
        """Create an instance of PhysicalCardResponseStatus from a dict"""
        if obj is None:
            return None

        if type(obj) is not dict:
            return PhysicalCardResponseStatus.parse_obj(obj)

        _obj = PhysicalCardResponseStatus.parse_obj({
            "card_status": obj.get("card_status"),
            "memo": obj.get("memo"),
            "status_reason": obj.get("status_reason"),
            "card_fulfillment_status": obj.get("card_fulfillment_status"),
            "fulfillment_details": FulfillmentDetails.from_dict(obj.get("fulfillment_details")) if obj.get("fulfillment_details") is not None else None,
            "tracking_number": obj.get("tracking_number")
        })
        return _obj




# coding: utf-8

"""
    Synctera API

    <h2>Let's build something great.</h2><p>Welcome to the official reference documentation for Synctera APIs. Our APIs are the best way to automate your company's banking needs and are designed to be easy to understand and implement.</p><p>We're continuously growing this library and what you see here is just the start, but if you need something specific or have a question, <a class='text-blue-600' href='https://synctera.com/contact' target='_blank' rel='noreferrer'>contact us</a>.</p>  # noqa: E501

    The version of the OpenAPI document: 0.41.0
    Contact: dev@swadesh.co
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


from __future__ import annotations
from inspect import getfullargspec
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from typing import Dict, Optional
from pydantic import BaseModel, Field, StrictBool, StrictStr, constr, validator
from synctera_client_ng.models.card_brand import CardBrand
from synctera_client_ng.models.card_status import CardStatus
from synctera_client_ng.models.card_status_reason_code import CardStatusReasonCode
from synctera_client_ng.models.emboss_name import EmbossName

class VirtualCardResponse(BaseModel):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """
    form: StrictStr = ...
    account_id: StrictStr = Field(..., description="The ID of the account to which the card will be linked")
    card_product_id: StrictStr = Field(..., description="The card product to which the card is attached")
    creation_time: datetime = Field(..., description="The timestamp representing when the card issuance request was made")
    customer_id: StrictStr = Field(..., description="The ID of the customer to whom the card will be issued")
    emboss_name: EmbossName = ...
    expiration_month: StrictStr = ...
    expiration_time: Optional[datetime] = Field(None, description="The timestamp representing when the card would expire at")
    expiration_year: StrictStr = ...
    id: StrictStr = Field(..., description="Card ID")
    is_pin_set: Optional[StrictBool] = Field(False, description="indicates whether a pin has been set on the card")
    last_four: StrictStr = Field(..., description="The last 4 digits of the card PAN")
    last_modified_time: Optional[datetime] = Field(None, description="The timestamp representing when the card was last modified at")
    metadata: Optional[Dict[str, StrictStr]] = Field(None, description="Additional data to include in the request structured as key-value pairs")
    reissue_reason: Optional[StrictStr] = Field(None, description="This is the reason the card needs to be reissued, if any. The reason determines several behaviours:   - whether or not the new card will use the same PAN as the original card   - the old card will be terminated and if so, when it will be terminated  Reason                 | Same PAN | Terminate Old Card ---------------------- | -------- | ------------------ EXPIRATION             | yes      | on activation LOST                   | no       | immediately STOLEN                 | no       | immediately DAMAGED                | yes      | on activation VIRTUAL_TO_PHYSICAL(*) | yes      | on activation PRODUCT_CHANGE         | yes      | on activation NAME_CHANGE(**)        | yes      | on activation APPEARANCE             | yes      | on activation  (*) VIRTUAL_TO_PHYSICAL is deprecated. Please use PRODUCT_CHANGE whenever reissuing from one card product to another, including from a virtual product to a physical product.  (**) NAME_CHANGE is deprecated. Please use APPEARANCE whenever reissuing in order to change the appearance of a card, such as the printed name or custom image.  For all reasons, the new card will use the same PIN as the original card and digital wallet tokens will reassigned to the new card ")
    reissued_from_id: Optional[StrictStr] = Field(None, description="When reissuing a card, specify the card to be replaced here. When getting a card's details, if this card was issued as a reissuance of another card, this ID refers to the card was replaced. If this field is set, then reissue_reason must also be set. ")
    reissued_to_id: Optional[StrictStr] = Field(None, description="If this card was reissued, this ID refers to the card that replaced it.")
    type: StrictStr = Field(..., description="Indicates the type of card to be issued")
    card_status: CardStatus = ...
    memo: Optional[constr(strict=True, max_length=255)] = Field(None, description="Additional details about the reason for the status change")
    status_reason: CardStatusReasonCode = ...
    bin: Optional[StrictStr] = Field(None, description="The bin number")
    card_brand: CardBrand = ...
    __properties = ["form", "account_id", "card_product_id", "creation_time", "customer_id", "emboss_name", "expiration_month", "expiration_time", "expiration_year", "id", "is_pin_set", "last_four", "last_modified_time", "metadata", "reissue_reason", "reissued_from_id", "reissued_to_id", "type", "card_status", "memo", "status_reason", "bin", "card_brand"]

    @validator('form')
    def form_validate_enum(cls, v):
        if v not in ('VIRTUAL'):
            raise ValueError("must validate the enum values ('VIRTUAL')")
        return v

    @validator('reissue_reason')
    def reissue_reason_validate_enum(cls, v):
        if v is None:
            return v

        if v not in ('EXPIRATION', 'LOST', 'STOLEN', 'DAMAGED', 'NAME_CHANGE', 'VIRTUAL_TO_PHYSICAL', 'PRODUCT_CHANGE', 'APPEARANCE'):
            raise ValueError("must validate the enum values ('EXPIRATION', 'LOST', 'STOLEN', 'DAMAGED', 'NAME_CHANGE', 'VIRTUAL_TO_PHYSICAL', 'PRODUCT_CHANGE', 'APPEARANCE')")
        return v

    @validator('type')
    def type_validate_enum(cls, v):
        if v not in ('DEBIT'):
            raise ValueError("must validate the enum values ('DEBIT')")
        return v

    class Config:
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> VirtualCardResponse:
        """Create an instance of VirtualCardResponse from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                            "creation_time",
                            "expiration_month",
                            "expiration_time",
                            "expiration_year",
                            "id",
                            "is_pin_set",
                            "last_four",
                            "last_modified_time",
                            "reissued_to_id",
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of emboss_name
        if self.emboss_name:
            _dict['emboss_name'] = self.emboss_name.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> VirtualCardResponse:
        """Create an instance of VirtualCardResponse from a dict"""
        if obj is None:
            return None

        if type(obj) is not dict:
            return VirtualCardResponse.parse_obj(obj)

        _obj = VirtualCardResponse.parse_obj({
            "form": obj.get("form"),
            "account_id": obj.get("account_id"),
            "card_product_id": obj.get("card_product_id"),
            "creation_time": obj.get("creation_time"),
            "customer_id": obj.get("customer_id"),
            "emboss_name": EmbossName.from_dict(obj.get("emboss_name")) if obj.get("emboss_name") is not None else None,
            "expiration_month": obj.get("expiration_month"),
            "expiration_time": obj.get("expiration_time"),
            "expiration_year": obj.get("expiration_year"),
            "id": obj.get("id"),
            "is_pin_set": obj.get("is_pin_set") if obj.get("is_pin_set") is not None else False,
            "last_four": obj.get("last_four"),
            "last_modified_time": obj.get("last_modified_time"),
            "metadata": obj.get("metadata"),
            "reissue_reason": obj.get("reissue_reason"),
            "reissued_from_id": obj.get("reissued_from_id"),
            "reissued_to_id": obj.get("reissued_to_id"),
            "type": obj.get("type"),
            "card_status": obj.get("card_status"),
            "memo": obj.get("memo"),
            "status_reason": obj.get("status_reason"),
            "bin": obj.get("bin"),
            "card_brand": obj.get("card_brand")
        })
        return _obj




# coding: utf-8

"""
    Synctera API

    <h2>Let's build something great.</h2><p>Welcome to the official reference documentation for Synctera APIs. Our APIs are the best way to automate your company's banking needs and are designed to be easy to understand and implement.</p><p>We're continuously growing this library and what you see here is just the start, but if you need something specific or have a question, <a class='text-blue-600' href='https://synctera.com/contact' target='_blank' rel='noreferrer'>contact us</a>.</p>  # noqa: E501

    The version of the OpenAPI document: 0.41.0
    Contact: dev@swadesh.co
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


from __future__ import annotations
from inspect import getfullargspec
import pprint
import re  # noqa: F401
import json


from typing import List, Optional
from pydantic import BaseModel, Field, StrictBool, StrictStr, conint, conlist, constr, validator
from synctera_client_ng.models.balance_ceiling import BalanceCeiling
from synctera_client_ng.models.balance_floor import BalanceFloor
from synctera_client_ng.models.spending_limits import SpendingLimits

class TemplateFieldsDepository(BaseModel):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """
    account_type: StrictStr = ...
    bank_country: constr(strict=True) = Field(..., description="Bank country of the account. ISO 3166-1 Alpha-2 or Alpha-3 country code.")
    currency: constr(strict=True) = Field(..., description="Account currency. ISO 4217 alphabetic currency code")
    balance_ceiling: Optional[BalanceCeiling] = None
    balance_floor: Optional[BalanceFloor] = None
    fee_product_ids: Optional[conlist(StrictStr)] = Field(None, description="A list of fee account products that the current account associates with.")
    interest_product_id: Optional[StrictStr] = Field(None, description="An interest account product that the current account associates with. ")
    is_ach_enabled: Optional[StrictBool] = Field(False, description="Enable ACH transaction.")
    is_card_enabled: Optional[StrictBool] = Field(False, description="Enable card transaction.")
    is_external_card_enabled: Optional[StrictBool] = Field(False, description="Enable external card transaction.")
    is_p2p_enabled: Optional[StrictBool] = Field(False, description="Enable P2P transaction.")
    is_sar_enabled: Optional[StrictBool] = Field(False, description="Enable SAR report.")
    is_wire_enabled: Optional[StrictBool] = Field(False, description="Enable wire transaction.")
    overdraft_limit: Optional[conint(strict=True, ge=0)] = Field(None, description="This field is unused and will be removed in a future API version. ")
    spend_control_ids: Optional[conlist(StrictStr, max_items=10)] = Field(None, description="List of spend control IDs to control spending for the account")
    spending_limits: Optional[SpendingLimits] = None
    __properties = ["account_type", "bank_country", "currency", "balance_ceiling", "balance_floor", "fee_product_ids", "interest_product_id", "is_ach_enabled", "is_card_enabled", "is_external_card_enabled", "is_p2p_enabled", "is_sar_enabled", "is_wire_enabled", "overdraft_limit", "spend_control_ids", "spending_limits"]

    @validator('bank_country')
    def bank_country_validate_regular_expression(cls, v):
        if v is None:
            return v
        if not re.match(r"^[A-Z]{2,3}$", v):
            raise ValueError(r"must validate the regular expression /^[A-Z]{2,3}$/")
        return v

    @validator('currency')
    def currency_validate_regular_expression(cls, v):
        if v is None:
            return v
        if not re.match(r"^[A-Z]{3}$", v):
            raise ValueError(r"must validate the regular expression /^[A-Z]{3}$/")
        return v

    class Config:
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> TemplateFieldsDepository:
        """Create an instance of TemplateFieldsDepository from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of balance_ceiling
        if self.balance_ceiling:
            _dict['balance_ceiling'] = self.balance_ceiling.to_dict()
        # override the default output from pydantic by calling `to_dict()` of balance_floor
        if self.balance_floor:
            _dict['balance_floor'] = self.balance_floor.to_dict()
        # override the default output from pydantic by calling `to_dict()` of spending_limits
        if self.spending_limits:
            _dict['spending_limits'] = self.spending_limits.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> TemplateFieldsDepository:
        """Create an instance of TemplateFieldsDepository from a dict"""
        if obj is None:
            return None

        if type(obj) is not dict:
            return TemplateFieldsDepository.parse_obj(obj)

        _obj = TemplateFieldsDepository.parse_obj({
            "account_type": obj.get("account_type"),
            "bank_country": obj.get("bank_country"),
            "currency": obj.get("currency"),
            "balance_ceiling": BalanceCeiling.from_dict(obj.get("balance_ceiling")) if obj.get("balance_ceiling") is not None else None,
            "balance_floor": BalanceFloor.from_dict(obj.get("balance_floor")) if obj.get("balance_floor") is not None else None,
            "fee_product_ids": obj.get("fee_product_ids"),
            "interest_product_id": obj.get("interest_product_id"),
            "is_ach_enabled": obj.get("is_ach_enabled") if obj.get("is_ach_enabled") is not None else False,
            "is_card_enabled": obj.get("is_card_enabled") if obj.get("is_card_enabled") is not None else False,
            "is_external_card_enabled": obj.get("is_external_card_enabled") if obj.get("is_external_card_enabled") is not None else False,
            "is_p2p_enabled": obj.get("is_p2p_enabled") if obj.get("is_p2p_enabled") is not None else False,
            "is_sar_enabled": obj.get("is_sar_enabled") if obj.get("is_sar_enabled") is not None else False,
            "is_wire_enabled": obj.get("is_wire_enabled") if obj.get("is_wire_enabled") is not None else False,
            "overdraft_limit": obj.get("overdraft_limit"),
            "spend_control_ids": obj.get("spend_control_ids"),
            "spending_limits": SpendingLimits.from_dict(obj.get("spending_limits")) if obj.get("spending_limits") is not None else None
        })
        return _obj




# coding: utf-8

"""
    Synctera API

    <h2>Let's build something great.</h2><p>Welcome to the official reference documentation for Synctera APIs. Our APIs are the best way to automate your company's banking needs and are designed to be easy to understand and implement.</p><p>We're continuously growing this library and what you see here is just the start, but if you need something specific or have a question, <a class='text-blue-600' href='https://synctera.com/contact' target='_blank' rel='noreferrer'>contact us</a>.</p>  # noqa: E501

    The version of the OpenAPI document: 0.41.0
    Contact: dev@swadesh.co
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


from __future__ import annotations
from inspect import getfullargspec
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from typing import Any, Dict, Optional
from pydantic import BaseModel, Field, StrictStr, validator
from synctera_client_ng.models.additional_owner_data import AdditionalOwnerData

class PatchPersonBusinessOwnerRelationshipAllOf(BaseModel):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """
    additional_data: Optional[AdditionalOwnerData] = None
    creation_time: Optional[datetime] = Field(None, description="The date and time the resource was created.")
    from_person_id: Optional[StrictStr] = Field(None, description="Unique ID for the subject person. ")
    id: Optional[StrictStr] = Field(None, description="Relationship unique identifier.")
    last_updated_time: Optional[datetime] = Field(None, description="The date and time the resource was last updated.")
    metadata: Optional[Dict[str, Any]] = Field(None, description="Optional field to store additional information about the resource. Intended to be used by the integrator to store non-sensitive data. ")
    relationship_type: StrictStr = Field(..., description="The relationship type. One of the following: * `BENEFICIAL_OWNER_OF` – a person who directly or indirectly owns a portion of the business. * `MANAGING_PERSON_OF` – a person who is an officer, director, or other notable person of an organization. * `OWNER_OF` – a business with ownership of another business. ")
    to_business_id: Optional[StrictStr] = Field(None, description="Unique ID for the related business. ")
    __properties = ["additional_data", "creation_time", "from_person_id", "id", "last_updated_time", "metadata", "relationship_type", "to_business_id"]

    @validator('relationship_type')
    def relationship_type_validate_enum(cls, v):
        if v not in ('BENEFICIAL_OWNER_OF', 'MANAGING_PERSON_OF', 'OWNER_OF'):
            raise ValueError("must validate the enum values ('BENEFICIAL_OWNER_OF', 'MANAGING_PERSON_OF', 'OWNER_OF')")
        return v

    class Config:
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> PatchPersonBusinessOwnerRelationshipAllOf:
        """Create an instance of PatchPersonBusinessOwnerRelationshipAllOf from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                            "creation_time",
                            "id",
                            "last_updated_time",
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of additional_data
        if self.additional_data:
            _dict['additional_data'] = self.additional_data.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> PatchPersonBusinessOwnerRelationshipAllOf:
        """Create an instance of PatchPersonBusinessOwnerRelationshipAllOf from a dict"""
        if obj is None:
            return None

        if type(obj) is not dict:
            return PatchPersonBusinessOwnerRelationshipAllOf.parse_obj(obj)

        _obj = PatchPersonBusinessOwnerRelationshipAllOf.parse_obj({
            "additional_data": AdditionalOwnerData.from_dict(obj.get("additional_data")) if obj.get("additional_data") is not None else None,
            "creation_time": obj.get("creation_time"),
            "from_person_id": obj.get("from_person_id"),
            "id": obj.get("id"),
            "last_updated_time": obj.get("last_updated_time"),
            "metadata": obj.get("metadata"),
            "relationship_type": obj.get("relationship_type"),
            "to_business_id": obj.get("to_business_id")
        })
        return _obj




from __future__ import absolute_import

# flake8: noqa

# import apis into api package
from synctera_client_ng.api.ach_api import ACHApi
from synctera_client_ng.api.ach_transaction_simulations_api import ACHTransactionSimulationsApi
from synctera_client_ng.api.accounts_api import AccountsApi
from synctera_client_ng.api.businesses_api import BusinessesApi
from synctera_client_ng.api.card_transaction_simulations_api import CardTransactionSimulationsApi
from synctera_client_ng.api.card_webhook_simulations_api import CardWebhookSimulationsApi
from synctera_client_ng.api.cards_api import CardsApi
from synctera_client_ng.api.cash_pickups_alpha_api import CashPickupsAlphaApi
from synctera_client_ng.api.customers_api import CustomersApi
from synctera_client_ng.api.digital_wallet_tokens_api import DigitalWalletTokensApi
from synctera_client_ng.api.disclosures_api import DisclosuresApi
from synctera_client_ng.api.disclosures_deprecated_api import DisclosuresDeprecatedApi
from synctera_client_ng.api.documents_api import DocumentsApi
from synctera_client_ng.api.external_accounts_api import ExternalAccountsApi
from synctera_client_ng.api.external_cards_api import ExternalCardsApi
from synctera_client_ng.api.internal_accounts_api import InternalAccountsApi
from synctera_client_ng.api.internal_transfer_api import InternalTransferApi
from synctera_client_ng.api.kyckyb_verifications_api import KYCKYBVerificationsApi
from synctera_client_ng.api.kyc_verification_deprecated_api import KYCVerificationDeprecatedApi
from synctera_client_ng.api.monitoring_api import MonitoringApi
from synctera_client_ng.api.notes_api import NotesApi
from synctera_client_ng.api.payment_schedules_api import PaymentSchedulesApi
from synctera_client_ng.api.persons_api import PersonsApi
from synctera_client_ng.api.relationships_api import RelationshipsApi
from synctera_client_ng.api.remote_check_deposit_beta_api import RemoteCheckDepositBetaApi
from synctera_client_ng.api.sandbox_wipe_alpha_api import SandboxWipeAlphaApi
from synctera_client_ng.api.spend_controls_beta_api import SpendControlsBetaApi
from synctera_client_ng.api.statements_api import StatementsApi
from synctera_client_ng.api.transactions_api import TransactionsApi
from synctera_client_ng.api.watchlist_deprecated_api import WatchlistDeprecatedApi
from synctera_client_ng.api.webhooks_api import WebhooksApi
from synctera_client_ng.api.wires_alpha_api import WiresAlphaApi
